@@ -228,7 +228,9 @@ sub resolve {
             require Sisimai::MIME;
 
             # Convert from string to hash reference
-            my $v          = $bouncedata->{'rfc822'} // $bodystring;
+            my $v =  $bouncedata->{'rfc822'} || $bodystring;
+               $v =~ s/^[>]+[ ]//mg;
+
             my @rfc822text = split( "\n", $v );
             my $rfc822head = Sisimai::MTA->RFC822HEADERS;
             my $previousfn = ''; # Previous field name
@@ -258,6 +260,7 @@ sub resolve {
                         if( $previousfn eq 'subject' ) {
                             # Subject: header
                             $rfc822part->{ $previousfn } .= $borderline.$e;
+
                         } else {
                             # Is not Subject header
                             $rfc822part->{ $previousfn } .= $e;
@@ -266,8 +269,8 @@ sub resolve {
 
                     } else {
                         # ASCII Characters only: Not MIME-Encoded
-                        $rfc822part->{ $previousfn } .= $e;
-                        $mimeborder->{ $previousfn }  = 0;
+                        $rfc822part->{ $previousfn }  .= $e;
+                        $mimeborder->{ $previousfn } //= 0;
                     }
                 }
             }
@@ -283,13 +286,20 @@ sub resolve {
 
                 } else {
                     # MIME-Encoded subject field or ASCII characters only
-                    if( Sisimai::MIME->is_mimeencoded( \$v ) ) {
-                        # MIME-Encoded subject such as ISO-2022-JP, UTF-8...
-                        my $r = [ $v ];
+                    my $r = [];
 
-                        $r = [ split( $borderline, $v ) ] if $mimeborder->{'subject'};
-                        $v = Sisimai::MIME->mimedecode( $r );
+                    if( $mimeborder->{'subject'} ) {
+                        # split the value of Subject by $borderline
+                        for my $m ( split( $borderline, $v ) ) {
+                            # Insert value to the array if the string is MIME
+                            # encoded text
+                            push @$r, $m if Sisimai::MIME->is_mimeencoded( \$m );
+                        }
+                    } else {
+                        # Subject line is not MIME encoded
+                        $r = [ $v ];
                     }
+                    $v = Sisimai::MIME->mimedecode( $r );
                 }
                 $rfc822part->{'subject'} = $v;
             } 
@@ -385,7 +395,7 @@ __END__
 
 =head1 NAME
 
-Sisimai::Message - Convert email text to data structure.
+Sisimai::Message - Convert bounce email text to data structure.
 
 =head1 SYNOPSIS
 
@@ -397,11 +407,18 @@ Sisimai::Message - Convert email text to data structure.
         my $p = Sisimai::Message->new( 'data' => $r );
     }
 
+    my $notmail = '/home/neko/Maildir/cur/22222';   # is not a bounce email
+    my $mailobj = Sisimai::Mail->new( $notmail );
+    while( my $r = $mailobj->read ) {
+        my $p = Sisimai::Message->new( 'data' => $r );  # $p is "undef"
+    }
+
 =head1 DESCRIPTION
 
-Sisimai::Message convert email text to data structure. It resolve email text
-into an UNIX From line, the header part of the mail, delivery status, and RFC822
-header part.
+Sisimai::Message convert bounce email text to data structure. It resolve email
+text into an UNIX From line, the header part of the mail, delivery status, and
+RFC822 header part. When the email given as a argument of "new" method is not a
+bounce email, the method returns "undef".
 
 =head1 CLASS METHODS
 
