@@ -7,39 +7,45 @@ sub text  { 'notaccept' }
 sub match {
     my $class = shift;
     my $argvs = shift // return undef;
-    my $regex = qr!(?:  # Destination mail server does not accept any message
-         dns[ ]lookup[ ]failure:[ ].+[ ]try[ ]again[ ]later
-        |domain[ ]does[ ]not[ ]exist:
-        |greylisted.?.[ ]please[ ]try[ ]again[ ]in
-        |http://(?:
-             www[.]spamhaus[.]org
-            |dsbl[.]org
-            |www[.]sorbs[.]net
-            )
-        |blocked[ ]for[ ]abuse[.][ ]see[ ]http://att[.]net/blocks   # AT&T
-        |invalid[ ]domain,[ ]see[ ][<]url:.+[>]
-        |ip[ ]\d{1,3}[.]\d{1,3}[.]\d{1,3}[.]\d{1,3}[ ]is[ ]blocked[ ]by[ ]earthlink # Earthlink
-        |listed[ ]in[ ]work[.]drbl[.]imedia[.]ru
-        |mail[ ]server[ ]at[ ].+[ ]is[ ]blocked
-        |message[ ]rejected[ ]for[ ]policy[ ]reasons
-        |mx[ ]records[ ]for[ ].+[ ]violate[ ]section[ ].+
-        |name[ ]service[ ]error[ ]for[ ]    # Malformed MX RR or host not found
-        |rfc[ ]1035[ ]violation:[ ]recursive[ ]cname[ ]records[ ]for
-        |rule[ ]imposed[ ]as[ ].+is[ ]blacklisted[ ]on              # Mailmarshal RBLs
-        |smtp[ ]protocol[ ]returned[ ]a[ ]permanent[ ]error
-        |the[ ](?:email|domain|ip).+[ ]is[ ]blacklisted
-        |we[ ]do[ ]not[ ]accept[ ]mail[ ]from[ ](?: # @mail.ru
-             hosts[ ]with[ ]dynamic[ ]ip[ ]or[ ]generic[ ]dns[ ]ptr-records
-            |dynamic[ ]ips
-            )
-        )
-    !xi;
+
+    # Destination mail server does not accept any message
+    my $regex = qr/smtp[ ]protocol[ ]returned[ ]a[ ]permanent[ ]error/xi;
 
     return 1 if $argvs =~ $regex;
     return 0;
 }
 
-sub true { return undef };
+sub true {
+    # @Description  Remote host does not accept any message
+    # @Param <obj>  (Sisimai::Data) Object
+    # @Return       (Integer) 1 = Not accept
+    #               (Integer) 0 = accept
+    # @See          http://www.ietf.org/rfc/rfc2822.txt
+    my $class = shift;
+    my $argvs = shift // return undef;
+
+    return undef unless ref $argvs eq 'Sisimai::Data';
+    my $reasontext = __PACKAGE__->text;
+
+    return 1 if $argvs->reason eq $reasontext;
+
+    my $diagnostic = $argvs->diagnosticcode // '';
+    my $v = 0;
+
+    if( $argvs->replycode =~ m/\A(?:521|554|556)\z/ ) {
+        # SMTP Reply Code is 554 or 556
+        $v = 1;
+
+    } else {
+        # Check the value of Diagnosic-Code: header with patterns
+        if( $argvs->smtpcommand eq 'MAIL' ) {
+            # Matched with a pattern in this class
+            $v = 1 if __PACKAGE__->match( $diagnostic );
+        }
+    }
+
+    return $v;
+}
 
 1;
 __END__
