@@ -42,6 +42,7 @@ sub match {
                 |user(?:[ ]here)?
                 )
             |[ ].+[ ]in[ ]name[ ]directory
+            |valid[ ]recipients[,][ ]bye    # Microsoft
             )
         |non[- ]?existent[ ]user
         |not[ ](?:
@@ -64,6 +65,7 @@ sub match {
             |unknown
             )
         |requested[ ]action[ ]not[ ]taken:[ ]mailbox[ ]unavailable
+        |RESOLVER[.]ADR[.]RecipNotFound # Microsoft
         |said:[ ]550[-[ ]]5[.]1[.]1[ ].+[ ]user[ ]unknown[ ]
         |sorry,[ ](?:
              user[ ]unknown
@@ -74,9 +76,11 @@ sub match {
               following[ ]recipients[ ]was[ ]undeliverable
              |user[']s[ ]email[ ]name[ ]is[ ]not[ ]found
              )
-        |this[ ]address[ ]no[ ]longer[ ]accepts[ ]mail
-        |this[ ]email[ ]address[ ]is[ ]wrong[ ]or[ ]no[ ]longer[ ]valid
-        |this[ ]user[ ]doesn[']?t[ ]have[ ]a[ ].+[ ]account
+        |this[ ](?:
+             address[ ]no[ ]longer[ ]accepts[ ]mail
+            |email[ ]address[ ]is[ ]wrong[ ]or[ ]no[ ]longer[ ]valid
+            |user[ ]doesn[']?t[ ]have[ ]a[ ].+[ ]account
+            )
         |unknown[ ](?:
              address
             |e[-]?mail[ ]address
@@ -115,7 +119,7 @@ sub true {
     return 1 if $argvs->reason eq __PACKAGE__->text;
 
     require Sisimai::RFC3463;
-    my $prematches = [ 'RelayingDenied', 'NotAccept', 'MailboxFull' ];
+    my $prematches = [ 'NoRelaying', 'Blocked', 'MailboxFull', 'HasMoved' ];
     my $matchother = 0;
     my $statuscode = $argvs->deliverystatus // '';
     my $reasontext = __PACKAGE__->text;
